@@ -32,6 +32,7 @@ class SyncJobAdmin(admin.ModelAdmin):
 class ConnectWiseBoardAdmin(admin.ModelAdmin):
     list_display = ('id', 'name', 'inactive')
     search_fields = ['name']
+    list_filter = ('inactive',)
 
 
 @admin.register(models.BoardStatus)
@@ -101,26 +102,30 @@ class CompanyTypeAdmin(admin.ModelAdmin):
 @admin.register(models.ScheduleType)
 class ScheduleTypeAdmin(admin.ModelAdmin):
     list_display = ('id', 'name', 'identifier')
-    list_filter = ('name', )
     search_fields = ['name']
 
 
 @admin.register(models.ScheduleStatus)
 class ScheduleStatusAdmin(admin.ModelAdmin):
     list_display = ('id', 'name')
-    list_filter = ('name', )
     search_fields = ['name']
 
 
 @admin.register(models.ScheduleEntry)
 class ScheduleEntryAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name', 'expected_date_start', 'expected_date_end',
-                    'done_flag', 'ticket_object', 'activity_object', 'member',
-                    'where', 'status', 'schedule_type')
-    list_filter = ('where', 'status', 'schedule_type')
+    list_display = ('id', 'ticket_object', 'activity_object', 'member',
+                    'done_flag',
+                    'status', 'date_start', 'date_end',)
+    list_filter = ('status', 'done_flag', 'member')
     search_fields = ['name', 'ticket_object__id',
                      'activity_object__id', 'member__identifier']
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.select_related(
+            'ticket_object', 'activity_object', 'member', 'status'
+        )
+
 
 @admin.register(models.TimeEntry)
 class TimeEntryAdmin(admin.ModelAdmin):
@@ -128,10 +133,14 @@ class TimeEntryAdmin(admin.ModelAdmin):
                     'member', 'billable_option', 'actual_hours',
                     'time_start', 'time_end', 'hours_deduct', 'notes',
                     'internal_notes')
-    list_filter = ('charge_to_id', 'member', 'charge_to_type')
+    list_filter = ('member', 'charge_to_type')
     search_fields = ['id', 'charge_to_id__id', 'member__identifier',
                      'charge_to_type']
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.select_related('company', 'member', 'charge_to_id')
+
 
 @admin.register(models.Team)
 class TeamAdmin(admin.ModelAdmin):
@@ -152,10 +161,23 @@ class ProjectStatusAdmin(admin.ModelAdmin):
     search_fields = ['name']
 
 
+@admin.register(models.ProjectType)
+class ProjectTypeAdmin(admin.ModelAdmin):
+    list_display = ('id', 'name', 'default_flag', 'inactive_flag')
+    list_filter = ('default_flag', 'inactive_flag',)
+    search_fields = ['name']
+
+
+@admin.register(models.ProjectPhase)
+class ProjectPhase(admin.ModelAdmin):
+    list_display = ('id', 'description', 'project')
+    search_fields = ['description']
+
+
 @admin.register(models.Project)
 class ProjectAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name', 'status', )
-    list_filter = ('status', )
+    list_display = ('id', 'name', 'status', 'type')
+    list_filter = ('status', 'type')
     search_fields = ['name']
 
 
@@ -208,17 +230,38 @@ class TicketAdmin(admin.ModelAdmin):
         return qs.select_related('status', 'status__board')
 
 
+@admin.register(models.ActivityStatus)
+class ActivityStatusAdmin(admin.ModelAdmin):
+    list_display = ('id', 'name', 'inactive_flag', 'closed_flag')
+    list_filter = ('inactive_flag', 'closed_flag')
+    search_fields = ['name']
+
+
+@admin.register(models.ActivityType)
+class ActivityTypeAdmin(admin.ModelAdmin):
+    list_display = ('id', 'name', 'points', 'inactive_flag')
+    list_filter = ('inactive_flag',)
+    search_fields = ['name']
+
+
 @admin.register(models.Activity)
 class ActivityAdmin(admin.ModelAdmin):
     list_display = ('id', 'name', 'notes', 'date_start', 'date_end',
                     'assign_to', 'opportunity', 'ticket')
-    list_filter = ['opportunity', ]
-    search_fields = ['name', 'notes']
+    search_fields = [
+        'name', 'notes', 'ticket__summary', 'opportunity__name',
+        'company__name'
+    ]
+    list_filter = ('status', 'type')
 
     formfield_overrides = {
         db_models.CharField: {'widget': TextInput(attrs={'size': '40'})}
     }
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.select_related('ticket', 'opportunity', 'assign_to')
+
 
 @admin.register(models.SalesProbability)
 class SalesProbabilityAdmin(admin.ModelAdmin):
@@ -262,7 +305,7 @@ class MyCompanyOtherAdmin(admin.ModelAdmin):
 
 @admin.register(models.Holiday)
 class Holiday(admin.ModelAdmin):
-    list_display = ('id', 'name',)
+    list_display = ('id', 'name', 'date')
     search_fields = ['name', 'date']
 
 
@@ -288,3 +331,22 @@ class SubType(admin.ModelAdmin):
 class Item(admin.ModelAdmin):
     list_display = ('id', 'name', 'board',)
     search_fields = ['name']
+
+
+@admin.register(models.WorkType)
+class WorkType(admin.ModelAdmin):
+    list_display = ('id', 'name', 'inactive_flag',)
+    search_fields = ['name']
+
+
+@admin.register(models.WorkRole)
+class WorkRole(admin.ModelAdmin):
+    list_display = ('id', 'name', 'inactive_flag',)
+    search_fields = ['name']
+
+
+@admin.register(models.Agreement)
+class Agreement(admin.ModelAdmin):
+    list_display = ('id', '__str__', 'company', 'cancelled_flag',
+                    'bill_time', 'work_type', 'work_role')
+    search_fields = ['name']
