@@ -1,12 +1,76 @@
 from django.conf import settings
 
+API_WORK_ROLE = {
+        "id": 11,
+        "name": "System Engineer",
+        "hourlyRate": 100,
+        "inactiveFlag": False,
+        "locationIds": [
+            2
+        ],
+        "_info": {
+            "lastUpdated": "2003-08-21T13:02:52Z",
+            "updatedBy": "zAdmin"
+        }
+    }
+
+API_WORK_ROLE_LIST = [API_WORK_ROLE]
+
+API_WORK_TYPE = {
+        "id": 4,
+        "name": "After Hours",
+        "billTime": "Billable",
+        "rateType": "Multiplier",
+        "rate": 2.5,
+        "hoursMin": 0.5,
+        "hoursMax": 0,
+        "roundBillHoursTo": 0.5,
+        "externalIntegrationXRef": {
+            "id": 2,
+            "identifier": "Weekend After Hours",
+            "name": "Weekend and Holiday Time",
+            "_info": {
+                "workTypeExternalIntegration_href":
+                    "https://example.com/v4_6_release/apis/3.0"
+            }
+        },
+        "inactiveFlag": False,
+        "overallDefaultFlag": False,
+        "activityDefaultFlag": False,
+        "utilizationFlag": True,
+        "costMultiplier": 1,
+        "_info": {
+            "lastUpdated": "2019-09-09T17:37:19Z",
+            "updatedBy": "User1"
+        }
+    }
+
+API_WORK_TYPE_LIST = [API_WORK_TYPE]
+
 API_BOARD = {
     'id': 1,
     'name': 'Service A',
     'locationId': 1,
     'businessUnitId': 10,
     'inactiveFlag': False,
-    'projectFlag': False
+    'projectFlag': False,
+    'workRole': {
+        'id': API_WORK_ROLE['id'],
+        'name': API_WORK_ROLE['name'],
+        '_info': {
+            'workRole_href':
+                'https://example.com/v4_6_release/test'
+        }
+    },
+    'workType': {
+        'id': API_WORK_TYPE['id'],
+        'name': API_WORK_TYPE['name'],
+        '_info': {
+            'workType_href':
+                'https://example.com/v4_6_release/test'
+        }
+    },
+    'billTime': 'NoDefault',
 }
 
 API_BOARD_LIST = [API_BOARD]
@@ -90,7 +154,7 @@ API_COMPANY = {
         'id': 77,
         'name': 'Bob Dobbs',
         '_info': {
-            'contact_href': 'https: //some-host.com/v4_6_release/' +
+            'contact_href': 'https://example.com/v4_6_release/' +
                             'apis/3.0/company/contacts/77'
         }
     },
@@ -125,7 +189,7 @@ API_COMPANY = {
         'id': 11,
         'name': 'State',
         '_info': {
-            'taxCode_href': 'https: //some-host.com/v4_6_release/apis/3.0/finance/taxCodes/11'
+            'taxCode_href': 'https: //example.com/v4_6_release/apis/3.0/finance/taxCodes/11'
         }
     },
     'billingTerms': {
@@ -141,7 +205,7 @@ API_COMPANY = {
         'identifier': 'YourCompany',
         'name': 'TestCompany',
         '_info': {
-            'company_href': 'https: //some-host.com/v4_6_release/apis/3.0/company/companies/2'
+            'company_href': 'https: //example.com/v4_6_release/apis/3.0/company/companies/2'
         }
     },
     'billingSite': None,
@@ -192,7 +256,7 @@ API_MEMBER = {
         'identifier': 'User1',
         'name': 'Training User1',
         '_info': {
-            'member_href': 'https://some-host.com/v4_6_release/apis/3.0/system/members/176'
+            'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/176'
         }
     },
     'firstName': 'Training',
@@ -262,7 +326,7 @@ API_MEMBER = {
         'id': 1,
         'name': 'Tampa Office/Services',
         '_info': {
-            'board_href': 'https://some-host.com/v4_6_release/apis/3.0/service/boards/1'
+            'board_href': 'https://example.com/v4_6_release/apis/3.0/service/boards/1'
         }
     },
     'serviceDefaultDepartmentId': 10,
@@ -278,7 +342,7 @@ API_MEMBER = {
         'identifier': 'User1',
         'name': 'Training User1',
         '_info': {
-            'member_href': 'https://some-host.com/v4_6_release/apis/3.0/system/members/176'
+            'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/176'
         }
     },
     'timeReminderEmailFlag': False,
@@ -397,6 +461,39 @@ API_PROJECT_STATUSES = [
     }
 ]
 
+API_PROJECT_TYPES = [
+    {
+        'id': 6,
+        'name': 'Network',
+        'defaultFlag': True,
+        'inactiveFlag': False,
+        '_info': {
+            'lastUpdated': '2001-01-08T18:05:13Z',
+            'updatedBy': None
+        }
+    },
+    {
+        'id': 7,
+        'name': 'Contract Service',
+        'defaultFlag': False,
+        'inactiveFlag': False,
+        '_info': {
+            'lastUpdated': '2001-01-08T18:05:21Z',
+            'updatedBy': None
+        }
+    },
+    {
+        'id': 8,
+        'name': 'Implementations',
+        'defaultFlag': False,
+        'inactiveFlag': False,
+        '_info': {
+            'lastUpdated': '2001-01-08T18:05:40Z',
+            'updatedBy': None
+        }
+    },
+]
+
 
 API_PROJECT = {
     'id': 5,
@@ -426,7 +523,7 @@ API_PROJECT = {
         'id': 70,
         'name': 'Gregg Kegle',
         '_info': {
-            'contact_href': 'https://some-host.com/v4_6_release/apis/3.0/company/contacts/70'
+            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/70'
         }
     },
     'customerPO': '',
@@ -437,7 +534,7 @@ API_PROJECT = {
         'isoCode': 'USD',
         'name': 'US Dollars',
         '_info': {
-            'currency_href': 'https://some-host.com/v4_6_release/apis/3.0/finance/currencies/7'
+            'currency_href': 'https://example.com/v4_6_release/apis/3.0/finance/currencies/7'
         }
     },
     'downpayment': 0,
@@ -460,14 +557,14 @@ API_PROJECT = {
         'id': 28,
         'name': 'Main',
         '_info': {
-            'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
+            'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
         }
     },
     'site': {
         'id': 28,
         'name': 'Main',
         '_info': {
-            'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
+            'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
         }
     },
     'status': API_PROJECT_STATUSES[0],
@@ -484,6 +581,69 @@ API_PROJECT = {
 
 API_PROJECT_LIST = [API_PROJECT]
 
+API_PROJECT_PHASE = {
+    'id': 1,
+    'projectId': API_PROJECT['id'],
+    'description': 'Project Management',
+    'board': {
+        'id': 3,
+        'name': 'Windows',
+        '_info': {
+            'board_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3'
+        }
+    },
+    'status': {
+        'id': 1,
+        'name': 'Open',
+        '_info': {
+            'status_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/project/phaseStatuses/1'
+        }
+    },
+    'wbsCode': '1',
+    'billTime': 'Billable',
+    'billExpenses': 'Billable',
+    'billProducts': 'Billable',
+    'markAsMilestoneFlag': False,
+    'notes': '\n',
+    'billSeparatelyFlag': False,
+    'billingMethod': 'ActualRates',
+    'scheduledHours': 9,
+    'scheduledStart': '2005-05-02T12:00:00Z',
+    'scheduledEnd': '2017-07-26T19:00:00Z',
+    'actualHours': 8,
+    'actualStart': '2005-05-02T00:00:00Z',
+    'actualEnd': '2005-08-23T00:00:00Z',
+    'budgetHours': 14,
+    'locationId': 2,
+    'businessUnitId': 10,
+    'hourlyRate': 0,
+    'billPhaseClosedFlag': False,
+    'billProjectClosedFlag': False,
+    'downpayment': 0,
+    'poAmount': 0,
+    'estimatedTimeCost': 0,
+    'estimatedExpenseCost': 0,
+    'estimatedProductCost': 0,
+    'estimatedTimeRevenue': 0,
+    'estimatedExpenseRevenue': 0,
+    'estimatedProductRevenue': 0,
+    'currency': {
+        'id': 7,
+        'symbol': '$',
+        'isoCode': 'USD',
+        'name': 'US Dollars',
+        '_info': {
+            'currency_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/currencies/7'
+        }
+    },
+    '_info': {
+        'lastUpdated': '2005-05-26T14:39:26Z',
+        'updatedBy': 'User10'
+    }
+}
+
+API_PROJECT_PHASE_LIST = [API_PROJECT_PHASE]
+
 API_SERVICE_LOCATION = {
     'id': 1,
     'name': 'On-Site',
@@ -501,8 +661,8 @@ API_SERVICE_PRIORITY = {
     'sortOrder': 6,
     'color': 'blue',
     '_info': {
-        'priority_href': 'https://some-host.com/v4_6_release/apis/3.0/service/priorities/4',
-        'image_href': 'https://some-host.com/v4_6_release/'
+        'priority_href': 'https://example.com/v4_6_release/apis/3.0/service/priorities/4',
+        'image_href': 'https://example.com/v4_6_release/'
             'apis/3.0/service/priorities/4/image?lm=2005-05-27T14:58:21Z'
     }
 }
@@ -528,7 +688,7 @@ API_SERVICE_TEAM_LIST = [
         'members': [179, 176, 181, 183, 185],
         'name': 'Windows Team',
         'notifyOnTicketDelete': False,
-        'teamLeader': {'_info': {'member_href': 'https://some-host.com/v4_6_release/apis/3.0/system/members/186'},
+        'teamLeader': {'_info': {'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/186'},
                        'id': 186,
                        'identifier': 'User10',
                        'name': 'Training User10'}},
@@ -542,7 +702,7 @@ API_SERVICE_TEAM_LIST = [
         'members': [202, 191, 189, 193, 195],
         'name': 'Network Team',
         'notifyOnTicketDelete': False,
-        'teamLeader': {'_info': {'member_href': 'https://some-host.com/v4_6_release/apis/3.0/system/members/186'},
+        'teamLeader': {'_info': {'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/186'},
                        'id': 186,
                        'identifier': 'User10',
                        'name': 'Training User10'}},
@@ -556,7 +716,7 @@ API_SERVICE_TEAM_LIST = [
         'members': [180, 178, 187, 186, 182, 184],
         'name': 'Linux Team',
         'notifyOnTicketDelete': False,
-        'teamLeader': {'_info': {'member_href': 'https://some-host.com/v4_6_release/apis/3.0/system/members/189'},
+        'teamLeader': {'_info': {'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/189'},
                        'id': 189,
                        'identifier': 'User13',
                        'name': 'Training User13'}
@@ -660,7 +820,7 @@ API_TYPE = {
         'id': 2,
         'name': 'Tampa Office',
         '_info': {
-            'location_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/locations/2'
+            'location_href': 'https://example.com/v4_6_release/apis/3.0/system/locations/2'
         }
     },
     'department': {
@@ -668,7 +828,7 @@ API_TYPE = {
         'identifier': 'Admin',
         'name': 'Admin',
         '_info': {
-            'department_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/departments/13'
+            'department_href': 'https://example.com/v4_6_release/apis/3.0/system/departments/13'
         }
     },
     '_info': {
@@ -715,27 +875,19 @@ API_ITEM_LIST = [API_ITEM]
 API_SERVICE_TICKET = {
     'id': 69,
     'summary': 'Schedule and Execute Conversion',
-    'recordType': 'ProjectTicket',
+    'recordType': 'ServiceTicket',
     'board': {
         'id': 1,
         'name': 'Service A',
         '_info': {
-            'board_href': 'https://some-host.com/v4_6_release/apis/3.0/service/boards/1'
+            'board_href': 'https://example.com/v4_6_release/apis/3.0/service/boards/1'
         }
     },
     'status': {
         'id': 1,
         'name': 'New',
         '_info': {
-            'status_href': 'https://some-host.com/v4_6_release/apis/3.0/service/boards/1/statuses/1'
-        }
-    },
-    'project': API_PROJECT,
-    'phase': {
-        'id': 8,
-        'name': 'Solution Implementation',
-        '_info': {
-            'phase_href': 'https://some-host.com/v4_6_release/apis/3.0/project/projects/5/phases/8'
+            'status_href': 'https://example.com/v4_6_release/apis/3.0/service/boards/1/statuses/1'
         }
     },
     'wbsCode': '10.2',
@@ -744,7 +896,7 @@ API_SERVICE_TICKET = {
         'id': 28,
         'name': 'Main',
         '_info': {
-            'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
+            'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/24/sites/28'
         }
     },
     'siteName': None,
@@ -758,7 +910,7 @@ API_SERVICE_TICKET = {
         'id': 70,
         'name': 'Gregg Kegle',
         '_info': {
-            'contact_href': 'https://some-host.com/v4_6_release/apis/3.0/company/contacts/70'
+            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/70'
         }
     },
     'contactName': 'Gregg Kegle',
@@ -780,7 +932,7 @@ API_SERVICE_TICKET = {
         'id': 2,
         'name': 'Phone',
         '_info': {
-            'source_href': 'https://some-host.com/v4_6_release/apis/3.0/service/sources/2'
+            'source_href': 'https://example.com/v4_6_release/apis/3.0/service/sources/2'
         }
     },
     'requiredDate': "2017-03-03T00:00:00Z",
@@ -839,14 +991,14 @@ API_SERVICE_TICKET = {
     '_info': {
         'lastUpdated': '2016-03-08T21:59:20Z',
         'updatedBy': 'User1',
-        'activities_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/activities',
-        'timeentries_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/timeentries',
-        'scheduleentries_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/scheduleentries',
-        'documents_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/documents',
-        'products_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/products',
-        'configurations_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/configurations',
-        'tasks_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/tasks',
-        'notes_href': 'https://some-host.com/v4_6_release/apis/3.0/service/tickets/69/notes'
+        'activities_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/activities',
+        'timeentries_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/timeentries',
+        'scheduleentries_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/scheduleentries',
+        'documents_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/documents',
+        'products_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/products',
+        'configurations_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/configurations',
+        'tasks_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/tasks',
+        'notes_href': 'https://example.com/v4_6_release/apis/3.0/service/tickets/69/notes'
     },
     'customFields': None
 }
@@ -861,6 +1013,127 @@ API_SERVICE_TICKET_MAP = {
 }
 
 
+API_PROJECT_TICKET = {
+    'id': 47,
+    'summary': "Senior Engineer Project Planning",
+    'isIssueFlag': False,
+    'board': {
+        'id': API_BOARD['id'],
+        'name': API_BOARD['name'],
+        '_info': {
+            'board_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3"
+        }
+    },
+    'status': {
+        'id': 1,
+        'name': "New",
+        '_info': {
+            'status_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3/statuses/1"
+        }
+    },
+    'project': API_PROJECT,
+    'phase': {
+        'id': API_PROJECT_PHASE['id'],
+        'name': API_PROJECT_PHASE['description'],
+        '_info': {
+            'phase_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/project/projects/4/phases/1"
+        }
+    },
+    'wbsCode': "1.1",
+    'company': API_COMPANY,
+    'site': {
+        'id': 9,
+        'name': "Main",
+        '_info': {
+            'site_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/company/companies/10/sites/9",
+            'mobileGuid': "7606ac88-1326-4dc6-a620-daf7d9ed3c70"
+        }
+    },
+    'siteName': "Main",
+    'addressLine1': "100 Hanrahan Ave.",
+    'city': "Atlanta",
+    'stateIdentifier': "GA",
+    'contact': {
+        'id': 26,
+        'name': "Gus Johnson",
+        '_info': {
+            'mobileGuid': "c5221fb2-6d13-4a5b-80a1-c06d714fd93d",
+            'contact_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/company/contacts/26"
+        }
+    },
+    'contactName': "Gus Johnson",
+    'contactPhoneNumber': "8138318954",
+    'contactEmailAddress': "gus.johnson@digitaltorch.com",
+    'type': API_TYPE_LIST[0],
+    'subType': API_SUBTYPE_LIST[0],
+    'item': API_ITEM_LIST[0],
+    'owner': API_MEMBER,
+    'priority': API_SERVICE_PRIORITY,
+    'serviceLocation': {
+        'id': API_SERVICE_LOCATION['id'],
+        'name': API_SERVICE_LOCATION['name']
+    },
+    'source': {
+        'id': 2,
+        'name': "Phone",
+        '_info': {
+            'source_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/sources/2"
+        }
+    },
+    'requiredDate': "2017-03-03T00:00:00Z",
+    'budgetHours': 12.00,
+    'allowAllClientsPortalView': False,
+    'customerUpdatedFlag': False,
+    'automaticEmailContactFlag': False,
+    'automaticEmailResourceFlag': False,
+    'automaticEmailCcFlag': False,
+    'automaticEmailCc': 'some_email@email.com',
+    'closedDate': "2018-08-30T19:28:23Z",
+    'closedBy': "kanban1",
+    'closedFlag': False,
+    'actualHours': 8.00,
+    'approved': True,
+    'resources': "User1, User10",
+    'billTime': "NoDefault",
+    'billExpenses': "Billable",
+    'billProducts': "Billable",
+    'agreement': None,
+    'location': {
+        'id': 2,
+        'name': "Tampa Office",
+        '_info': {
+            'location_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/locations/2"
+        }
+    },
+    'department': {
+        'id': 10,
+        'identifier': "Services",
+        'name': "Professional Services",
+        '_info': {
+            'department_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/departments/10"
+        }
+    },
+    'mobileGuid': "729d53ab-108e-4fbf-8ed3-5b0a260a8594",
+    'currency': {
+        'id': 7,
+        'symbol': "$",
+        'isoCode': "USD",
+        'name': "US Dollars",
+        '_info': {
+            'currency_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/currencies/7"
+        }
+    },
+    '_info': {
+        'lastUpdated': "2018-08-31T21:04:39Z",
+        'updatedBy': "kanban1",
+        'dateEntered': "2005-05-26T14:39:27Z",
+        'enteredBy': "User10"
+    }
+}
+
+API_PROJECT_TICKET_LIST = [API_PROJECT_TICKET]
+
+
 API_CW_VERSION = {
     'version': 'v2.0'
 }
@@ -887,6 +1160,43 @@ API_SYSTEM_TERRITORY = {
 
 API_SYSTEM_TERRITORY_LIST = [API_SYSTEM_TERRITORY]
 
+API_AGREEMENT = {
+    "id": 1,
+    "name": "Gold Rate",
+    "billTime": "Billable",
+    "company": {
+        "id": API_COMPANY["id"],
+        "name": API_COMPANY["name"],
+        "identifier": API_COMPANY["identifier"],
+    },
+    "cancelledFlag": False,
+    "type": {
+        "id": 5,
+        "name": "Block Time - One time",
+        "_info": {
+            "type_href":
+                "https://cw.com/v4_6_release/apis/3.0/finance/agreements/types"
+        }
+    },
+    "workRole": {
+        "id": API_WORK_ROLE['id'],
+        "name": API_WORK_ROLE['name'],
+        "_info": {
+            "workRole_href":
+                "https://cw.com/v4_6_release/apis/3.0/time/workRoles/18"
+        }
+    },
+    "workType": {
+        "id": API_WORK_TYPE['id'],
+        "name": API_WORK_TYPE['name'],
+        "_info": {
+            "workType_href":
+                "https://cw.com/v4_6_release/apis/3.0/time/workTypes/3"
+        }
+    }
+}
+
+API_AGREEMENT_LIST = [API_AGREEMENT]
 
 API_SALES_OPPORTUNITY_TYPE = {
     'id': 2,
@@ -970,28 +1280,28 @@ API_SALES_OPPORTUNITY_STAGES = [API_SALES_OPPORTUNITY_STAGE]
 
 API_SALES_OPPORTUNITY = {
     '_info': {'lastUpdated': '2016-10-12T19:24:07Z',
-              'notes_href': 'https://some-host.com/v4_6_release/apis/3.0/sales/opportunities/2/notes',
+              'notes_href': 'https://example.com/v4_6_release/apis/3.0/sales/opportunities/2/notes',
               'updatedBy': 'TaxUpdate'},
     'billToCompany':
-        {'_info': {'company_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/8'},
+        {'_info': {'company_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/8'},
          'id': 8,
          'identifier': 'AngryFoxCo',
          'name': 'Angry Fox, Co.'},
-    'billToContact': {'_info': {'contact_href': 'https://some-host.com/v4_6_release/apis/3.0/company/contacts/20'},
+    'billToContact': {'_info': {'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/20'},
                       'id': 20,
                       'name': 'Flin Storts'},
-    'billToSite': {'_info': {'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
+    'billToSite': {'_info': {'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
                    'id': 7,
                    'name': 'Main'},
     'billingTerms': {'_info': None, 'id': 2, 'name': 'Net 10 days'},
     'businessUnitId': 10,
-    'campaign': {'_info': {'campaign_href': 'https://some-host.com/v4_6_release/apis/3.0/marketing/campaigns/3'},
+    'campaign': {'_info': {'campaign_href': 'https://example.com/v4_6_release/apis/3.0/marketing/campaigns/3'},
                  'id': 3,
                  'name': 'Partner Referral'},
     'closedBy': API_MEMBER,
     'closedDate': '2005-09-09T19:53:52Z',
     'company': API_COMPANY,
-    'contact': {'_info': {'contact_href': 'https://some-host.com/v4_6_release/apis/3.0/company/contacts/20'},
+    'contact': {'_info': {'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/20'},
                 'id': 20,
                 'name': 'Flin Storts'},
     'customFields': None,
@@ -1006,26 +1316,26 @@ API_SALES_OPPORTUNITY = {
     'primarySalesRep': API_MEMBER,
     'priority': {'_info': None, 'id': 7, 'name': 'Clear Flag'},
     'probability': API_SALES_PROBABILITY,
-    'rating': {'_info': {'rating_href': 'https://some-host.com/v4_6_release/apis/3.0/sales/opportunities/ratings/4'},
+    'rating': {'_info': {'rating_href': 'https://example.com/v4_6_release/apis/3.0/sales/opportunities/ratings/4'},
                'id': 4,
                'name': 'Hot'},
     'secondarySalesRep': API_MEMBER,
     'shipToCompany': API_COMPANY,
-    'shipToContact': {'_info': {'contact_href': 'https://some-host.com/v4_6_release/apis/3.0/company/contacts/20'},
+    'shipToContact': {'_info': {'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/20'},
                       'id': 20,
                       'name': 'Flin Storts'},
-    'shipToSite': {'_info': {'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
+    'shipToSite': {'_info': {'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
                    'id': 7,
                    'name': 'Main'},
-    'site': {'_info': {'site_href': 'https://some-host.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
+    'site': {'_info': {'site_href': 'https://example.com/v4_6_release/apis/3.0/company/companies/8/sites/7'},
              'id': 7,
              'name': 'Main'},
     'source': 'Microsoft sent to us',
     'stage': {'_info': None, 'id': 8, 'name': '3.Quote'},
-    'status': {'_info': {'status_href': 'https://some-host.com/v4_6_release/apis/3.0/sales/opportunities/statuses/1'},
+    'status': {'_info': {'status_href': 'https://example.com/v4_6_release/apis/3.0/sales/opportunities/statuses/1'},
                'id': 1,
                'name': 'Open'},
-    'taxCode': {'_info': {'taxCode_href': 'https://some-host.com/v4_6_release/apis/3.0/finance/taxCodes/11'},
+    'taxCode': {'_info': {'taxCode_href': 'https://example.com/v4_6_release/apis/3.0/finance/taxCodes/11'},
                 'id': 11,
                 'name': 'State'},
     'totalSalesTax': 0.0,
@@ -1036,17 +1346,147 @@ API_SALES_OPPORTUNITIES = [
     API_SALES_OPPORTUNITY,
 ]
 
+API_SALES_ACTIVITY_STATUSES = [
+    {
+        "id": 1,
+        "name": "Open",
+        "defaultFlag": True,
+        "inactiveFlag": False,
+        "closedFlag": False,
+        "_info": {
+            "lastUpdated": "2000-12-28T22:34:26Z"
+        }
+    },
+    {
+        "id": 2,
+        "name": "Closed",
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "closedFlag": True,
+        "_info": {
+            "lastUpdated": "2000-12-28T22:34:35Z"
+        }
+    },
+    {
+        "id": 8,
+        "name": "Opened",
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "spawnFollowupFlag": False,
+        "closedFlag": False,
+        "_info": {
+            "lastUpdated": "2016-05-11T00:31:06Z",
+            "updatedBy": "User1"
+        }
+    }
+]
+
+API_SALES_ACTIVITY_TYPES = [
+    {
+        "id": 1,
+        "name": "Call",
+        "points": 2,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:52:58Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 2,
+        "name": "Appointment",
+        "points": 5,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:52:50Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 3,
+        "name": "Historical Entry",
+        "points": 0,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": True,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:53:45Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 5,
+        "name": "Quote",
+        "points": 5,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:54:17Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 6,
+        "name": "Follow Up",
+        "points": 1,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:53:31Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 7,
+        "name": "Email",
+        "points": 1,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": True,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:53:23Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+    {
+        "id": 8,
+        "name": "Task",
+        "points": 1,
+        "defaultFlag": False,
+        "inactiveFlag": False,
+        "emailFlag": False,
+        "memoFlag": False,
+        "historyFlag": False,
+        "_info": {
+            "lastUpdated": "2003-10-31T18:54:27Z",
+            "updatedBy": "zAdmin"
+        }
+    },
+]
+
 
 API_SALES_ACTIVITY = {
     'id': 47,
     'name': 'Stage Change from 1.Prospect to 2.Qualification',
-    'type': {
-        'id': 3,
-        'name': 'Historical Entry',
-        '_info': {
-            'type_href': 'https://example.com/v4_6_release/apis/3.0/sales/activities/types/3'
-        }
-    },
+    'type': API_SALES_ACTIVITY_TYPES[0],
     'company': API_COMPANY,
     'contact': {
         'id': 20,
@@ -1057,20 +1497,13 @@ API_SALES_ACTIVITY = {
     },
     'phoneNumber': '8139888241',
     'email': 'test@test.com',
-    'status': {
-        'id': 4,
-        'name': '1-High',
-        '_info': {
-            'status_href': 'https://example.com/v4_6_release/apis/3.0/sales/activities/statuses/4'
-        }
-    },
+    'status': API_SALES_ACTIVITY_STATUSES[0],
     'opportunity': API_SALES_OPPORTUNITY,
     'ticket': None,
-    'agreement': None,
+    'agreement': API_AGREEMENT,
     'campaign': None,
     'notes': 'Stage Change from 1.Prospect to 2.Qualification',
     'dateStart': '2016-03-06',
-    # 'dateEnd': None,                  # ConnectWise 2017.5 removed null values
     'assignedBy': {
         'id': 196,
         'identifier': 'User20',
@@ -1238,21 +1671,21 @@ API_TIME_ENTRY = {
         'id': 3,
         'name': 'Regular',
         '_info': {
-            'workType_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/workTypes/3'
+            'workType_href': 'https://example.com/v4_6_release/apis/3.0/system/workTypes/3'
         }
     },
     'workRole': {
         'id': 11,
         'name': 'System Engineer',
         '_info': {
-            'workRole_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/time/workRoles/11'
+            'workRole_href': 'https://example.com/v4_6_release/apis/3.0/time/workRoles/11'
         }
     },
     'agreement': {
         'id': 3,
         'name': 'Retainer Agreement for Big Design',
         '_info': {
-            'agreement_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/agreements/3'
+            'agreement_href': 'https://example.com/v4_6_release/apis/3.0/finance/agreements/3'
         }
     },
 
@@ -1274,7 +1707,7 @@ API_TIME_ENTRY = {
         'id': 4,
         'identifier': '3',
         '_info': {
-            'invoice_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/invoices/4'
+            'invoice_href': 'https://example.com/v4_6_release/apis/3.0/finance/invoices/4'
         }
     },
     'mobileGuid': '6fd34162-0856-4bc1-80ae-c3dccd89357a',
@@ -1283,7 +1716,7 @@ API_TIME_ENTRY = {
         'id': 2,
         'name': '2005-05-14 to 2005-05-20',
         '_info': {
-            'timeSheet_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/time/sheets/2'
+            'timeSheet_href': 'https://example.com/v4_6_release/apis/3.0/time/sheets/2'
         }
     },
     'status': 'Billed',
@@ -1295,3 +1728,86 @@ API_TIME_ENTRY = {
 }
 
 API_TIME_ENTRY_LIST = [API_TIME_ENTRY]
+
+API_HOSTED_SCREENS = {
+    "column_definitions": [
+        {
+            "Presenter_Identifier_Client_Api_RecID": {
+                "type": "Numeric",
+                "isNullable": False,
+                "identityColumn": True
+            }
+        },
+        {
+            "Client_Api_ID": {
+                "type": "Text",
+                "isNullable": False,
+                "identityColumn": False
+            }
+        }
+    ],
+    "row_values": [
+        [
+            1, "CompanyDetail"
+        ],
+        [
+            2, "ContactDetail"
+        ],
+        [
+            3, "ConnectWiseToday"
+        ],
+        [
+            4, "ServiceTicket"
+        ],
+        [
+            5, "ProjectTicket"
+        ],
+        [
+            6, "SalesOrderDetail"
+        ],
+        [
+            7, "CompanyFinanceDetail"
+        ],
+    ]
+}
+
+API_HOSTED_SETUPS = [
+    {
+        "id": 2,
+        "screenId": 3,
+        "description": "ConnectWise University",
+        "url": "https://university.connectwise.com/university/",
+        "type": "Tab",
+        "disabledFlag": False,
+        "locationIds": [
+            2,
+            42
+        ],
+        "locationsEnabledFlag": True,
+        "createdBy": "zadmin",
+        "dateCreated": "2017-01-27T05:44:04Z",
+        "_info": {
+            "lastUpdated": "2017-01-27T05:44:04Z",
+            "updatedBy": "zadmin"
+        }
+    },
+    {
+        "id": 4,
+        "screenId": 5,
+        "description": "Kanban Testing",
+        "url": "https://opprimo.serveo.net/all-tickets/cwhostedembed/ ",
+        "type": "Tab",
+        "origin": "https://opprimo.serveo.net/",
+        "toolbarButtonDialogHeight": 0,
+        "toolbarButtonDialogWidth": 0,
+        "disabledFlag": False,
+        "locationIds": [],
+        "locationsEnabledFlag": False,
+        "createdBy": "User1",
+        "dateCreated": "2019-02-20T20:31:30Z",
+        "_info": {
+            "lastUpdated": "2019-04-10T23:42:24Z",
+            "updatedBy": "User1"
+        }
+    }
+]
